package com.ruoyi.web.controller.invest;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.system.domain.invest.TProjectChannel;
import com.ruoyi.system.service.invest.ITProjectChannelService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 渠道信息Controller
 * 
 * @author ruoyi
 * @date 2024-02-22
 */
@RestController
@RequestMapping("/invest/channel")
public class TProjectChannelController extends BaseController
{
    @Autowired
    private ITProjectChannelService tProjectChannelService;

    /**
     * 查询渠道信息列表
     */
    @PreAuthorize("@ss.hasPermi('invest:channel:list')")
    @GetMapping("/list")
    public TableDataInfo list(TProjectChannel tProjectChannel)
    {
        startPage();
        List<TProjectChannel> list = tProjectChannelService.selectTProjectChannelList(tProjectChannel);
        return getDataTable(list);
    }

    /**
     * 导出渠道信息列表
     */
    @PreAuthorize("@ss.hasPermi('invest:channel:export')")
    @Log(title = "渠道信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TProjectChannel tProjectChannel)
    {
        List<TProjectChannel> list = tProjectChannelService.selectTProjectChannelList(tProjectChannel);
        ExcelUtil<TProjectChannel> util = new ExcelUtil<TProjectChannel>(TProjectChannel.class);
        util.exportExcel(response, list, "渠道信息数据");
    }

    /**
     * 获取渠道信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('invest:channel:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return success(tProjectChannelService.selectTProjectChannelById(id));
    }

    /**
     * 新增渠道信息
     */
    @PreAuthorize("@ss.hasPermi('invest:channel:add')")
    @Log(title = "渠道信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TProjectChannel tProjectChannel)
    {
        return toAjax(tProjectChannelService.insertTProjectChannel(tProjectChannel));
    }

    /**
     * 修改渠道信息
     */
    @PreAuthorize("@ss.hasPermi('invest:channel:edit')")
    @Log(title = "渠道信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TProjectChannel tProjectChannel)
    {
        return toAjax(tProjectChannelService.updateTProjectChannel(tProjectChannel));
    }

    /**
     * 删除渠道信息
     */
    @PreAuthorize("@ss.hasPermi('invest:channel:remove')")
    @Log(title = "渠道信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        return toAjax(tProjectChannelService.deleteTProjectChannelByIds(ids));
    }
}
