package com.ruoyi.web.controller.invest;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.system.domain.invest.TProjectInformation;
import com.ruoyi.system.service.invest.ITProjectInformationService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 文件资料Controller
 * 
 * @author ruoyi
 * @date 2024-02-22
 */
@RestController
@RequestMapping("/invest/information")
public class TProjectInformationController extends BaseController
{
    @Autowired
    private ITProjectInformationService tProjectInformationService;

    /**
     * 查询文件资料列表
     */
    @PreAuthorize("@ss.hasPermi('invest:information:list')")
    @GetMapping("/list")
    public TableDataInfo list(TProjectInformation tProjectInformation)
    {
        startPage();
        List<TProjectInformation> list = tProjectInformationService.selectTProjectInformationList(tProjectInformation);
        return getDataTable(list);
    }

    /**
     * 导出文件资料列表
     */
    @PreAuthorize("@ss.hasPermi('invest:information:export')")
    @Log(title = "文件资料", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TProjectInformation tProjectInformation)
    {
        List<TProjectInformation> list = tProjectInformationService.selectTProjectInformationList(tProjectInformation);
        ExcelUtil<TProjectInformation> util = new ExcelUtil<TProjectInformation>(TProjectInformation.class);
        util.exportExcel(response, list, "文件资料数据");
    }

    /**
     * 获取文件资料详细信息
     */
    @PreAuthorize("@ss.hasPermi('invest:information:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return success(tProjectInformationService.selectTProjectInformationById(id));
    }

    /**
     * 新增文件资料
     */
    @PreAuthorize("@ss.hasPermi('invest:information:add')")
    @Log(title = "文件资料", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TProjectInformation tProjectInformation)
    {
        return toAjax(tProjectInformationService.insertTProjectInformation(tProjectInformation));
    }

    /**
     * 修改文件资料
     */
    @PreAuthorize("@ss.hasPermi('invest:information:edit')")
    @Log(title = "文件资料", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TProjectInformation tProjectInformation)
    {
        return toAjax(tProjectInformationService.updateTProjectInformation(tProjectInformation));
    }

    /**
     * 删除文件资料
     */
    @PreAuthorize("@ss.hasPermi('invest:information:remove')")
    @Log(title = "文件资料", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        return toAjax(tProjectInformationService.deleteTProjectInformationByIds(ids));
    }
}
