package com.ruoyi.web.controller.invest;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.system.domain.invest.TProjectPool;
import com.ruoyi.system.service.invest.ITProjectPoolService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 项目池Controller
 * 
 * @author ruoyi
 * @date 2024-02-21
 */
@RestController
@RequestMapping("/invest/pool")
public class TProjectPoolController extends BaseController
{
    @Autowired
    private ITProjectPoolService tProjectPoolService;

    /**
     * 查询项目池列表
     */
    @PreAuthorize("@ss.hasPermi('invest:pool:list')")
    @GetMapping("/list")
    public TableDataInfo list(TProjectPool tProjectPool)
    {
        startPage();
        List<TProjectPool> list = tProjectPoolService.selectTProjectPoolList(tProjectPool);
        return getDataTable(list);
    }

    /**
     * 导出项目池列表
     */
    @PreAuthorize("@ss.hasPermi('invest:pool:export')")
    @Log(title = "项目池", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TProjectPool tProjectPool)
    {
        List<TProjectPool> list = tProjectPoolService.selectTProjectPoolList(tProjectPool);
        ExcelUtil<TProjectPool> util = new ExcelUtil<TProjectPool>(TProjectPool.class);
        util.exportExcel(response, list, "项目池数据");
    }

    /**
     * 获取项目池详细信息
     */
    @PreAuthorize("@ss.hasPermi('invest:pool:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return success(tProjectPoolService.selectTProjectPoolById(id));
    }

    /**
     * 新增项目池
     */
    @PreAuthorize("@ss.hasPermi('invest:pool:add')")
    @Log(title = "项目池", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TProjectPool tProjectPool)
    {
        return toAjax(tProjectPoolService.insertTProjectPool(tProjectPool));
    }

    /**
     * 修改项目池
     */
    @PreAuthorize("@ss.hasPermi('invest:pool:edit')")
    @Log(title = "项目池", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TProjectPool tProjectPool)
    {
        return toAjax(tProjectPoolService.updateTProjectPool(tProjectPool));
    }

    /**
     * 删除项目池
     */
    @PreAuthorize("@ss.hasPermi('invest:pool:remove')")
    @Log(title = "项目池", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        return toAjax(tProjectPoolService.deleteTProjectPoolByIds(ids));
    }
}
