package com.ruoyi.web.controller.invest;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.system.domain.invest.TProjectRecord;
import com.ruoyi.system.service.invest.ITProjectRecordService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 跟进记录Controller
 * 
 * @author ruoyi
 * @date 2024-02-21
 */
@RestController
@RequestMapping("/invest/record")
public class TProjectRecordController extends BaseController
{
    @Autowired
    private ITProjectRecordService tProjectRecordService;

    /**
     * 查询跟进记录列表
     */
    @PreAuthorize("@ss.hasPermi('invest:record:list')")
    @GetMapping("/list")
    public TableDataInfo list(TProjectRecord tProjectRecord)
    {
        startPage();
        List<TProjectRecord> list = tProjectRecordService.selectTProjectRecordList(tProjectRecord);
        return getDataTable(list);
    }

    /**
     * 导出跟进记录列表
     */
    @PreAuthorize("@ss.hasPermi('invest:record:export')")
    @Log(title = "跟进记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TProjectRecord tProjectRecord)
    {
        List<TProjectRecord> list = tProjectRecordService.selectTProjectRecordList(tProjectRecord);
        ExcelUtil<TProjectRecord> util = new ExcelUtil<TProjectRecord>(TProjectRecord.class);
        util.exportExcel(response, list, "跟进记录数据");
    }

    /**
     * 获取跟进记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('invest:record:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return success(tProjectRecordService.selectTProjectRecordById(id));
    }

    /**
     * 新增跟进记录
     */
    @PreAuthorize("@ss.hasPermi('invest:record:add')")
    @Log(title = "跟进记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TProjectRecord tProjectRecord)
    {
        return toAjax(tProjectRecordService.insertTProjectRecord(tProjectRecord));
    }

    /**
     * 修改跟进记录
     */
    @PreAuthorize("@ss.hasPermi('invest:record:edit')")
    @Log(title = "跟进记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TProjectRecord tProjectRecord)
    {
        return toAjax(tProjectRecordService.updateTProjectRecord(tProjectRecord));
    }

    /**
     * 删除跟进记录
     */
    @PreAuthorize("@ss.hasPermi('invest:record:remove')")
    @Log(title = "跟进记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        return toAjax(tProjectRecordService.deleteTProjectRecordByIds(ids));
    }
}
