package com.ruoyi.system.service.invest.impl;

import java.util.List;
import java.util.UUID;

import com.fasterxml.jackson.annotation.ObjectIdGenerators;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.uuid.IdUtils;
import com.ruoyi.system.domain.invest.TProjectPool;
import com.ruoyi.system.mapper.invest.TProjectPoolMapper;
import com.ruoyi.system.service.invest.ITProjectPoolService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * 项目池Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-02-21
 */
@Service
public class TProjectPoolServiceImpl implements ITProjectPoolService
{
    @Autowired
    private TProjectPoolMapper tProjectPoolMapper;

    /**
     * 查询项目池
     * 
     * @param id 项目池主键
     * @return 项目池
     */
    @Override
    public TProjectPool selectTProjectPoolById(String id)
    {
        return tProjectPoolMapper.selectTProjectPoolById(id);
    }

    /**
     * 查询项目池列表
     * 
     * @param tProjectPool 项目池
     * @return 项目池
     */
    @Override
    public List<TProjectPool> selectTProjectPoolList(TProjectPool tProjectPool)
    {
        return tProjectPoolMapper.selectTProjectPoolList(tProjectPool);
    }

    /**
     * 新增项目池
     * 
     * @param tProjectPool 项目池
     * @return 结果
     */
    @Override
    public int insertTProjectPool(TProjectPool tProjectPool)
    {
        tProjectPool.setCreateTime(DateUtils.getNowDate());
        tProjectPool.setId(IdUtils.fastSimpleUUID());
        return tProjectPoolMapper.insertTProjectPool(tProjectPool);
    }

    /**
     * 修改项目池
     * 
     * @param tProjectPool 项目池
     * @return 结果
     */
    @Override
    public int updateTProjectPool(TProjectPool tProjectPool)
    {
        tProjectPool.setUpdateTime(DateUtils.getNowDate());
        return tProjectPoolMapper.updateTProjectPool(tProjectPool);
    }

    /**
     * 批量删除项目池
     * 
     * @param ids 需要删除的项目池主键
     * @return 结果
     */
    @Override
    public int deleteTProjectPoolByIds(String[] ids)
    {
        return tProjectPoolMapper.deleteTProjectPoolByIds(ids);
    }

    /**
     * 删除项目池信息
     * 
     * @param id 项目池主键
     * @return 结果
     */
    @Override
    public int deleteTProjectPoolById(String id)
    {
        return tProjectPoolMapper.deleteTProjectPoolById(id);
    }
}
